@@ -198,7 +198,7 @@ class KinMS_plotter:
         mask[mask > 0] =1
         return mask
 
-    def makeplots(self, block=True, **kwargs):
+    def makeplots(self, block=True, plot2screen=True, **kwargs):
 
         # Create plot data from the cube
         self.mask=self.smoothmask(self.f)
@@ -303,11 +303,12 @@ class KinMS_plotter:
                     plt.savefig(self.savepath + '/' + 'KinMS_plots.pdf', bbox_inches='tight')
                 else:
                     plt.savefig(self.savepath + '/' + 'KinMS_plots.png', bbox_inches='tight')
-        if block==False:
-            plt.draw()
-            plt.pause(1e-6)
-        else:
-            plt.show()   
+        if plot2screen:            
+            if block==False:
+                plt.draw()
+                plt.pause(1e-6)
+            else:
+                plt.show()   
                  
 #=============================================================================#
 #/// END OF CLASS ////////////////////////////////////////////////////////////#
